powered by
Compares two parameter objects and produces a test for DIF based on equality of relative item difficulties category locations
DIF_mst(db, person_property, predicate = NULL)
an dexterMST db handle
name of a person property defined in your dexterMST project
logical predicate to select data to include in the analysis
Bechger, T. M. and Maris, G (2015); A Statistical Test for Differential Item Pair Functioning. Psychometrika. Vol. 80, no. 2, 317-340.
if (FALSE) { dif = DIF_mst(db, person_property = 'test_mode') print(dif) plot(dif) }
Run the code above in your browser using DataLab