plot.im_mst: plots for the interaction model

View source: R/interaction.R

plot.im_mstR Documentation

plots for the interaction model

Description

plots for the interaction model

Usage

## S3 method for class 'im_mst'
plot(x, item_id = NULL, show.observed = TRUE, curtains = 10, zoom = FALSE, ...)

Arguments

x

output of fit_inter_mst

item_id

id of the item to plot

show.observed

plot the observed mean item scores for each test score

curtains

percentage of most extreme values to cover with curtains, 0 to omit curtains

zoom

if TRUE, limits the plot area to the test score range allowed by the routing rules

...

further arguments to plot


dexter-psychometrics/dexterMST documentation built on June 9, 2025, 7:43 a.m.