profile_tables_mst: Profile analysis
Description
Expected and observed domain scores per booklet and test score
Usage
profile_tables_mst(parms, domains, item_property)
Value
a data.frame with expected score per domain, booklet and booklet_score
Arguments
- parms
An object returned by fit_enorm_mst
- domains
data.frame with column item_id and a column whose name matches `item_property`
- item_property
the name of the item property used to define the domains.